@@ -15,10 +15,10 @@
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
-(defparameter *autoconf-ld-flags* "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto")
+(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
 
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/build/maxima/src/maxima-5.48.1")
+(defparameter *maxima-source-root* "/buildsys/main/maxima/src/maxima-5.48.1")
 (defparameter *maxima-default-layout-autotools* "true")
